USE [master];
GO

IF DATABASEPROPERTYEX('$(DatabaseName)', 'Version') IS NOT NULL
BEGIN
	ALTER DATABASE $(DatabaseName)
	SET SINGLE_USER 
	WITH ROLLBACK IMMEDIATE;

	DROP DATABASE $(DatabaseName)
END
GO

CREATE DATABASE $(DatabaseName);
GO

USE $(DatabaseName);
GO
CREATE TABLE [dbo].[Clients] (
    [ClientGuid]         UNIQUEIDENTIFIER NOT NULL,
    [ClientName]         NVARCHAR (50)    NOT NULL,
    [ClientEmailAddress] VARCHAR (50)     NULL,
    [ClientPhoneNumber]  VARCHAR (20)     NULL,
    CONSTRAINT [PK_Clients] PRIMARY KEY CLUSTERED ([ClientGuid] ASC),
    CONSTRAINT [CK_Clients_ClientName_Length] CHECK (len([ClientName]) > (9))
);
GO
CREATE PROCEDURE [dbo].[CreateClient]
	@ClientGuid uniqueidentifier,
	@ClientName nvarchar(50),
	@ClientEmailAddress varchar(50),
	@ClientPhoneNumber varchar(20)
AS
BEGIN
	SET NOCOUNT ON;

	INSERT INTO dbo.Clients (
		ClientGuid,
		ClientName,
		ClientEmailAddress,
		ClientPhoneNumber
		)
	VALUES (
		@ClientGuid,
		@ClientName,
		@ClientEmailAddress,
		@ClientPhoneNumber
		);		
END
GO
CREATE PROCEDURE [dbo].[FindClientsByName]
	@Name nvarchar(50)
AS
BEGIN
	SET NOCOUNT ON;

	SELECT 
		ClientGuid, 
		ClientName, 
		ClientPhoneNumber
	FROM Clients
	WHERE ClientName LIKE '%' + ISNULL(@Name, '') + '%';

END
GO
